import argparse
import sys

from damsel_diary.diary_writer import DiaryWriter


def main() -> None:
    """A simple CLI diary for incremental extension."""
    try:
        parser = argparse.ArgumentParser(
            description="A simple CLI diary for incremental extension.",
            formatter_class=argparse.MetavarTypeHelpFormatter,
        )

        parser.add_argument(
            "subject",
            type=str,
            nargs="?",
            default="",
            help="subject of new entry extension",
        )
        parser.add_argument(
            "-hl",
            "--heading-level",
            type=int,
            default="2",
            help="level of new Markdown heading in the interval [2, 6]"
            " (default: 2)",
        )
        parser.add_argument(
            "-a",
            "--amend",
            action="store_true",
            help="open diary entry without creating a new heading",
        )
        parser.add_argument(
            "-t",
            "--template",
            type=str,
            default="default",
            help="template to add in entry",
        )
        args = parser.parse_args()

        diary = DiaryWriter()
        new_entry = diary.today(
            amend=args.amend,
            template_name=args.template,
            subject=args.subject,
            new_heading_level=args.heading_level,
        )
        diary.open_entry(new_entry)

    except Exception as e:
        print(str(e))
        sys.exit(2)


if __name__ == "__main__":
    main()
