from dataclasses import dataclass
from pathlib import Path

from damsel_diary.parsing import TemplateParser
from damsel_diary.time_format import TimeFormat


@dataclass(init=False)
class Entry:
    """Store information on an entry to be written."""

    file_path: Path
    template_path: Path
    time_format: TimeFormat

    def __init__(
        self, file_path: Path, template_path: Path, time_format: "TimeFormat"
    ) -> None:
        """Initialize an instance of Entry.

        Args:
            file_path (Path): The path to the entry.
            template_path (Path): The path to the template.
            time_format (TimeFormat): A TimeFormat instance.
        """
        self.file_path = file_path
        self.template_path = template_path
        self.time_format = time_format

        # If there is a file already present, read it's contents.
        try:
            with open(file_path, "r") as f:
                self.current_contents = f.read()

        # If there isn't, set the current_content to empty.
        except OSError:
            self.current_contents = ""

        # Parse the chosen template.
        self.parsed_template = TemplateParser(template_path).template_contents
