import re
import typing
from pathlib import Path


class TemplateParser:
    def __init__(self, template_path: Path) -> None:
        """Initialize an instance of TemplateParser.

        Args:
            template_path (Path): The path to the template in
            .damsel-diary/templates/.
        """
        with open(template_path, "r") as f:
            self.template_contents = f.read()

        self.parse_words()

    def parse_words(self) -> None:
        """Parse the words."""
        # TODO: Parse individual words for keywords.

        # Split the content into words, keeping whitespace characters.
        template_words = string_split_newlines(self.template_contents)

        for element in template_words:
            element = element.strip()  # Remove unnecessary whitespace.

        # Join words with a space character. If any spaces follow a
        # newline, then remove it.
        self.template_contents = " ".join(template_words).replace("\n ", "\n")


def string_split_newlines(string: str) -> typing.List[str]:
    """Split a string into words while keeping newline characters.

    Args:
        string (str): The string to split.

    Returns:
        typing.List[str]: A list of words.
    """
    return re.findall(r"\S+|\n", string)
